
# overgang -- Markov Models

The package includes 

* Continous-Time Markov model `ctmc_fit`


### Installation

It's a pip package at https://pypi.org/project/overgang/
```
pip install overgang
```


### Examples
Check the [examples](examples) folder for notebooks.
